package com.huiju.estateagents.property.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.huiju.estateagents.base.BaseController;
import com.huiju.estateagents.base.ResponseBean;
import com.huiju.estateagents.common.CommConstant;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import com.huiju.estateagents.property.service.ITpRepairTypeService;
import com.huiju.estateagents.property.entity.TpRepairType;
import org.springframework.web.bind.annotation.RestController;

import javax.servlet.http.HttpServletRequest;
import java.time.LocalDateTime;

/**
 * <p>
    * 工单报修分类表  前端控制器
    * </p>
 *
 * @author yansen
 * @since 2020-12-17
 */

@Api(tags = "工单报修分类表 ")
@RestController
@RequestMapping("/api")
public class TpRepairTypeController extends BaseController {

    private final Logger logger = LoggerFactory.getLogger(TpRepairTypeController.class);

    @Autowired
    public ITpRepairTypeService iTpRepairTypeService;


    /**
     * 分页查询列表
     * @param pageNum
     * @param pageSize
     * @return
     */
    @RequestMapping(value="/{client}/tpRepairType",method= RequestMethod.GET)
    @ApiOperation(value="列表", notes = "列表", httpMethod = "GET", response = ResponseBean.class)
    public ResponseBean tpRepairTypeList(@ApiParam(value = "客户端", allowableValues = "wx,admin") @PathVariable String client,
                                         @ApiParam("页码") @RequestParam(value ="pageNum",defaultValue = "1") Integer pageNum,
                                         @ApiParam("单页数据量") @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize,
                                         HttpServletRequest request) throws Exception{

        Integer orgId = getOrgId(request);

        IPage<TpRepairType> pg = new Page<>(pageNum, pageSize);
        QueryWrapper<TpRepairType> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq("org_id", orgId);
        queryWrapper.eq("wx".equals(client),"status", CommConstant.STATUS_NORMAL);
        queryWrapper.gt("admin".equals(client),"status", CommConstant.STATUS_DELETE);
        queryWrapper.orderByDesc("sort_num");
        queryWrapper.orderByDesc("created_time");

        IPage<TpRepairType> result = iTpRepairTypeService.page(pg, queryWrapper);
        return ResponseBean.success(result);
    }

    /**
     * 保存对象
     * @param tpRepairType 实体对象
     * @return
     */
    @RequestMapping(value="/admin/tpRepairType",method= RequestMethod.POST)
    @ApiOperation(value="保存", notes = "保存", httpMethod = "POST", response = ResponseBean.class)
    public ResponseBean tpRepairTypeAdd(@ApiParam("保存内容") @RequestBody TpRepairType tpRepairType,
                                        HttpServletRequest request) throws Exception{
        Integer orgId = getOrgId(request);

        tpRepairType.setOrgId(orgId);
        if (null == tpRepairType.getStatus()) {
            tpRepairType.setStatus(CommConstant.STATUS_NORMAL);
        }
        tpRepairType.setCreatedTime(LocalDateTime.now());

        if (iTpRepairTypeService.save(tpRepairType)){
            return ResponseBean.success(tpRepairType);
        }else {
            return ResponseBean.error("保存失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
        }
    }

    /**
     * 根据id删除对象
     * @param id  实体ID
     */
    @RequestMapping(value="/admin/tpRepairType/{id}", method= RequestMethod.DELETE)
    @ApiOperation(value="删除", notes = "删除", httpMethod = "DELETE", response = ResponseBean.class)
    public ResponseBean tpRepairTypeDelete(@ApiParam("对象ID") @PathVariable Integer id,
                                           HttpServletRequest request) throws Exception{
        TpRepairType tpRepairType = iTpRepairTypeService.getById(id);
        tpRepairType.setStatus(CommConstant.STATUS_DELETE);
        return tpRepairTypeUpdate(tpRepairType.getTypeId(), tpRepairType, request);
    }

    /**
     * 修改对象
     * @param id  实体ID
     * @param tpRepairType 实体对象
     * @return
     */
    @RequestMapping(value="/admin/tpRepairType/{id}",method= RequestMethod.PUT)
    @ApiOperation(value="更新", notes = "更新", httpMethod = "PUT", response = ResponseBean.class)
    public ResponseBean tpRepairTypeUpdate(@ApiParam("对象ID") @PathVariable Integer id,
                                           @ApiParam("更新内容") @RequestBody TpRepairType tpRepairType,
                                           HttpServletRequest request) throws Exception{
        if (null == tpRepairType || tpRepairType.getStatus().equals(CommConstant.STATUS_DELETE) || !tpRepairType.getTypeId().equals(id) || !tpRepairType.getOrgId().equals(getOrgId(request))) {
            return ResponseBean.error("当前数据不存在", ResponseBean.ERROR_UNAVAILABLE);
        }

        tpRepairType.setUpdatedTime(LocalDateTime.now());

        if (iTpRepairTypeService.updateById(tpRepairType)){
            return ResponseBean.success(iTpRepairTypeService.getById(id));
        }else {
            return ResponseBean.error("修改失败, 请重试", ResponseBean.ERROR_UNAVAILABLE);
        }
    }

    /**
     * 根据id查询对象
     * @param id  实体ID
     */
    @RequestMapping(value="/{client}/tpRepairType/{id}",method= RequestMethod.GET)
    @ApiOperation(value="详情", notes = "详情", httpMethod = "GET", response = ResponseBean.class)
    public ResponseBean tpRepairTypeGet(@ApiParam("客户端") @PathVariable String client,
                                        @ApiParam("对象ID") @PathVariable Integer id,
                                        HttpServletRequest request) throws Exception{
        TpRepairType tpRepairType = iTpRepairTypeService.getById(id);
        if (null == tpRepairType || tpRepairType.getStatus().equals(CommConstant.STATUS_DELETE) || !tpRepairType.getOrgId().equals(getOrgId(request))) {
            return ResponseBean.error("当前数据不存在", ResponseBean.ERROR_UNAVAILABLE);
        }

        return ResponseBean.success(tpRepairType);
    }
}
